@@ -10,7 +10,7 @@
 // WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $Id: cycles.c 172 2009-01-16 10:36:59Z jessekornblum $
+// $Id: cycles.c 250 2010-12-15 19:12:06Z jessekornblum $
 
 #include "main.h"
 
@@ -52,7 +52,8 @@ int done_processing_dir(TCHAR *fn)
 #ifdef _WIN32
   _wfullpath(d_name,fn,PATH_MAX);
 #else
-  realpath(fn,d_name);
+  if (NULL == realpath(fn,d_name))
+    return TRUE;
 #endif
 
   if (my_table == NULL)
@@ -111,7 +112,8 @@ int processing_dir(TCHAR *fn)
 #ifdef _WIN32
   _wfullpath(d_name,fn,PATH_MAX);
 #else
-  realpath(fn,d_name);
+  if (NULL == realpath(fn,d_name))
+    return TRUE;
 #endif
 
   if (my_table == NULL)
@@ -165,7 +167,8 @@ int have_processed_dir(TCHAR *fn)
 #ifdef _WIN32
   _wfullpath(d_name,fn,PATH_MAX);
 #else
-  realpath(fn,d_name);
+  if (NULL == realpath(fn,d_name))
+    return TRUE;
 #endif
 
   temp = my_table;
