@@ -1,5 +1,5 @@
 
-// $Id: audit.c 207 2009-12-22 00:33:33Z jessekornblum $ 
+// $Id: audit.c 242 2010-11-29 22:19:40Z jessekornblum $ 
 
 #include "main.h"
 
@@ -63,7 +63,7 @@ int display_audit_results(state *s)
       print_status(" ");
       */
       print_status("          Files matched: %"PRIu64, s->match_exact);
-      print_status("Files paritally matched: %"PRIu64, s->match_partial);
+      print_status("Files partially matched: %"PRIu64, s->match_partial);
       print_status("            Files moved: %"PRIu64, s->match_moved);
       print_status("        New files found: %"PRIu64, s->match_unknown);
       print_status("  Known files not found: %"PRIu64, s->match_unused);
